==> orange_dam-1.2.3.tar.gz: orange_dam/src/OrangeDamConfigurationManager.php <==
<?php

namespace Drupal\orange_dam;

use Drupal\Core\Config\ConfigFactoryInterface;

/**
 * Manages the retrieval and validation of configuration.
 */
class OrangeDamConfigurationManager {

  /**
   * The Orange DAM configuration.
   */
  const ORANGE_DAM_CONFIG = 'orange_dam.settings';

  /**
   * Constructor.
   */
  public function __construct(
    protected ConfigFactoryInterface $configFactory,
  ) {}

  /**
   * Get an array of allowed content type names.
   *
   * @return string[]
   *   An array of allowed content type names.
   */
  public function getContentTypeNames(): array {
    $content_types = array_keys(
      $this->configFactory
        ->get(static::ORANGE_DAM_CONFIG)
        ->get('content_types')
    );
    if (empty($content_types)) {
      throw new \Exception(
        'Missing "orange_dam.settings content_types" configuration.'
      );
    }
    return $content_types;
  }

  /**
   * Get an array of allowed keyword types.
   *
   * @return string[]
   *   An array of allowed content types.
   */
  public function getKeywordTypes(): array {
    $tag_types = $this->configFactory
      ->get(static::ORANGE_DAM_CONFIG)
      ->get('tag_types');
    if (empty($tag_types)) {
      throw new \Exception(
        'Missing "orange_dam.settings tag_types" configuration.'
      );
    }
    return $tag_types;

  }

  /**
   * Get an array of allowed asset formats.
   *
   * @return string[]
   *   An array of allowed asset formats.
   */
  public function getAssetFormats(): array {
    // Retrieve and validate the asset format configuration.
    $asset_formats = $this->configFactory
      ->get(static::ORANGE_DAM_CONFIG)
      ->get('asset_formats');
    if (empty($asset_formats)) {
      throw new \Exception(
        'Missing "orange_dam.settings asset_formats" configuration.'
      );
    }
    return $asset_formats;
  }

}

==> orange_dam-1.2.4.tar.gz: orange_dam/src/OrangeDamConfigurationManager.php <==
<?php

namespace Drupal\orange_dam;

use Drupal\Core\Config\ConfigFactoryInterface;

/**
 * Manages the retrieval and validation of configuration.
 */
class OrangeDamConfigurationManager {

  /**
   * The Orange DAM configuration.
   */
  const ORANGE_DAM_CONFIG = 'orange_dam.settings';

  /**
   * Constructor.
   */
  public function __construct(
    protected ConfigFactoryInterface $configFactory,
  ) {}

  /**
   * Get an array of allowed content type names.
   *
   * @return string[]
   *   An array of allowed content type names.
   */
  public function getContentTypeNames(): array {
    return array_keys($this->getContentTypes());
  }

  /**
   * Get the content type configuration.
   *
   * @return array
   *   An array of content type configuration.
   */
  public function getContentTypes(): array {
    $content_types = $this->configFactory
      ->get(static::ORANGE_DAM_CONFIG)
      ->get('content_types');
    if (empty($content_types)) {
      throw new \Exception(
        'Missing "orange_dam.settings content_types" configuration.'
      );
    }
    return $content_types;
  }

  /**
   * Get an array of allowed keyword types.
   *
   * @return string[]
   *   An array of allowed content types.
   */
  public function getKeywordTypes(): array {
    $tag_types = $this->configFactory
      ->get(static::ORANGE_DAM_CONFIG)
      ->get('tag_types');
    if (empty($tag_types)) {
      throw new \Exception(
        'Missing "orange_dam.settings tag_types" configuration.'
      );
    }
    return $tag_types;

  }

  /**
   * Get an array of allowed asset formats.
   *
   * @return string[]
   *   An array of allowed asset formats.
   */
  public function getAssetFormats(): array {
    // Retrieve and validate the asset format configuration.
    $asset_formats = $this->configFactory
      ->get(static::ORANGE_DAM_CONFIG)
      ->get('asset_formats');
    if (empty($asset_formats)) {
      throw new \Exception(
        'Missing "orange_dam.settings asset_formats" configuration.'
      );
    }
    return $asset_formats;
  }

}
